# VmbPy 

**THIS IS AN UNOFFICIAL PUBLISH ON PYPI OF THE VmbPy API DEVELOPED BY Allied Vision Technologies GmbH !**  

This package is a Python wrapper for the Vimba C API provided by Allied Vision Technologies GmbH. 
It is intended to be used with Allied Vision cameras that are compatible with the Vimba SDK.

All the installation informatin can be found on the [Github repo](https://github.com/alliedvision/VmbPy).

---
@alliedvision If you want me to remove this package from PyPi, please create an issue on the [Github repo](https://github.com/EtchedChampion/drd-VmbPy).